@@ -1,5 +1,7 @@
 #' @title Add base maps to a time series data cube
 #' @name sits_add_base_cube
+#' @author Felipe Carlos, \email{efelipecarlos@@gmail.com}
+#' @author Felipe Carvalho, \email{felipe.carvalho@@inpe.br}
 #' @author Gilberto Camara, \email{gilberto.camara@@inpe.br}
 #'
 #' @description This function add base maps to time series data cube.
@@ -17,41 +19,41 @@
 #' @return a merged data cube with the inclusion of a base_info tibble
 #' @examples
 #' if (sits_run_examples()) {
-#'      s2_cube <- sits_cube(
-#'            source = "MPC",
-#'            collection = "SENTINEL-2-L2A",
-#'            tiles = "18HYE",
-#'            bands = c("B8A", "CLOUD"),
-#'            start_date = "2022-01-01",
-#'            end_date = "2022-03-31"
-#'            )
-#'      output_dir <- paste0(tempdir(), "/reg")
-#'      if (!dir.exists(output_dir)) {
-#'                dir.create(output_dir)
-#'      }
-#'      dem_cube <- sits_cube(
-#'            source = "MPC",
-#'            collection = "COP-DEM-GLO-30",
-#'            tiles = "18HYE",
-#'            bands = "ELEVATION"
-#'            )
-#'      s2_reg  <- sits_regularize(
-#'            cube = s2_cube,
-#'            period = "P1M",
-#'            res = 240,
-#'            output_dir = output_dir,
-#'            multicores = 2,
-#'            memsize = 4
-#'      )
-#'      dem_reg  <- sits_regularize(
-#'            cube = dem_cube,
-#'            res = 240,
-#'            tiles = "18HYE",
-#'            output_dir = output_dir,
-#'            multicores = 2,
-#'            memsize = 4
-#'      )
-#'      s2_reg <- sits_add_base_cube(s2_reg, dem_reg)
+#'     s2_cube <- sits_cube(
+#'         source = "MPC",
+#'         collection = "SENTINEL-2-L2A",
+#'         tiles = "18HYE",
+#'         bands = c("B8A", "CLOUD"),
+#'         start_date = "2022-01-01",
+#'         end_date = "2022-03-31"
+#'     )
+#'     output_dir <- paste0(tempdir(), "/reg")
+#'     if (!dir.exists(output_dir)) {
+#'         dir.create(output_dir)
+#'     }
+#'     dem_cube <- sits_cube(
+#'         source = "MPC",
+#'         collection = "COP-DEM-GLO-30",
+#'         tiles = "18HYE",
+#'         bands = "ELEVATION"
+#'     )
+#'     s2_reg <- sits_regularize(
+#'         cube = s2_cube,
+#'         period = "P1M",
+#'         res = 240,
+#'         output_dir = output_dir,
+#'         multicores = 2,
+#'         memsize = 4
+#'     )
+#'     dem_reg <- sits_regularize(
+#'         cube = dem_cube,
+#'         res = 240,
+#'         tiles = "18HYE",
+#'         output_dir = output_dir,
+#'         multicores = 2,
+#'         memsize = 4
+#'     )
+#'     s2_reg <- sits_add_base_cube(s2_reg, dem_reg)
 #' }
 #' @export
 #'
@@ -74,7 +76,7 @@ sits_add_base_cube <- function(cube1, cube2) {
         tile_cube1_tl <- .tile_timeline(tile_cube1)
         tile_cube2_tl <- .tile_timeline(tile_cube2)
         # align timelines
-        fi_cube2[["date"]] <- tile_cube1_tl[1:length(tile_cube2_tl)]
+        fi_cube2[["date"]] <- tile_cube1_tl[seq_along(tile_cube2_tl)]
         # update 2nd cube files
         .fi(tile_cube2) <- fi_cube2
         # append cube to base info
@@ -86,7 +88,6 @@ sits_add_base_cube <- function(cube1, cube2) {
         tile_cube1[["base_info"]] <- list(base_info)
         tile_cube1
     })
-    # update cube class
-    class(cube1) <- c("base_raster_cube", class(cube1))
-    cube1
+    # update cube class and return
+    .set_class(cube1, "base_raster_cube", class(cube1))
 }
