@@ -3,7 +3,7 @@
 #' @name sits_bands
 #'
 #' @author Gilberto Camara, \email{gilberto.camara@@inpe.br}
-#' @author Rolf Simoes, \email{rolf.simoes@@inpe.br}
+#' @author Rolf Simoes, \email{rolfsimoes@@gmail.com}
 #'
 #' @description
 #' Finds the names of the bands of a set of time series or of a data cube
@@ -36,7 +36,7 @@
 #'     sits_bands(samples_modis_ndvi) <- "NDVI2"
 #'     # Set the bands for a SITS cube
 #'     sits_bands(cube) <- "NDVI2"
-#'}
+#' }
 #' @export
 sits_bands <- function(x) {
     .check_set_caller("sits_bands")
@@ -46,7 +46,7 @@ sits_bands <- function(x) {
 #' @rdname sits_bands
 #' @export
 sits_bands.sits <- function(x) {
-    return(setdiff(names(.tibble_time_series(x)), "Index"))
+    setdiff(names(.tibble_time_series(x)), "Index")
 }
 #' @rdname sits_bands
 #' @export
@@ -55,22 +55,21 @@ sits_bands.raster_cube <- function(x) {
     .check_set_caller("sits_bands")
     bands_lst <- slider::slide(x, function(tile) {
         bands_tile <- .tile_bands(tile)
-        return(sort(bands_tile))
+        sort(bands_tile)
     })
     bands <- unique(bands_lst)
-    .check_that(length(bands) == 1)
-    return(unlist(bands))
+    .check_that(length(bands) == 1L)
+    unlist(bands)
 }
 #' @rdname sits_bands
 #' @export
 sits_bands.patterns <- function(x) {
-    return(sits_bands.sits(x))
+    sits_bands.sits(x)
 }
 #' @rdname sits_bands
 #' @export
 sits_bands.sits_model <- function(x) {
-    bands <- .ml_bands(x)
-    return(bands)
+    .ml_bands(x)
 }
 #' @rdname sits_bands
 #' @export
@@ -83,16 +82,14 @@ sits_bands.default <- function(x) {
     } else {
         stop(.conf("messages", "sits_bands_default"))
     }
-
-    bands <- sits_bands(x)
-    return(bands)
+    sits_bands(x)
 }
 #' @rdname sits_bands
 #' @export
 `sits_bands<-` <- function(x, value) {
     # set caller to show in errors
     .check_set_caller("sits_bands_assign")
-    .check_chr(value, len_min = 1)
+    .check_chr(value, len_min = 1L)
     value <- toupper(value)
     UseMethod("sits_bands<-", x)
 }
@@ -102,11 +99,10 @@ sits_bands.default <- function(x) {
 `sits_bands<-.sits` <- function(x, value) {
     bands <- .samples_bands(x)
     .check_that(length(bands) == length(value))
-    x <- .apply(x, col = "time_series", fn = function(x) {
+    .apply(x, col = "time_series", fn = function(x) {
         names(x) <- c("Index", value, "#..")
-        return(x)
+        x
     })
-    return(x)
 }
 #' @rdname sits_bands
 #' @export
@@ -114,11 +110,10 @@ sits_bands.default <- function(x) {
     bands <- .cube_bands(x)
     # precondition
     .check_that(length(bands) == length(value))
-    x <- slider::slide_dfr(x, function(tile) {
+    slider::slide_dfr(x, function(tile) {
         .tile_bands(tile) <- value
         tile
     })
-    return(x)
 }
 #' @rdname sits_bands
 #' @export
