@@ -1,6 +1,7 @@
 #' @title Merge two data sets (time series or cubes)
 #' @name sits_merge
-#' @author Gilberto Camara, \email{gilberto.camara@@inpe.br}
+#' @author Felipe Carvalho, \email{felipe.carvalho@@inpe.br}
+#' @author Felipe Carlos,   \email{efelipecarlos@@gmail.com}
 #'
 #' @description To merge two series, we consider that they contain different
 #' attributes but refer to the same data cube and spatiotemporal location.
@@ -60,10 +61,12 @@ sits_merge <- function(data1, data2, ...) {
 sits_merge.sits <- function(data1, data2, ..., suffix = c(".1", ".2")) {
     .check_set_caller("sits_merge_sits")
     # precondition - data sets are not empty
-    .check_that(nrow(data1) > 0 & nrow(data2) > 0)
+    .check_content_data_frame(data1)
+    .check_content_data_frame(data2)
     # check that data2 and data1 are sits tibble
     .check_samples_ts(data1)
     .check_samples_ts(data2)
+    data2 <- .samples_convert_to_sits(data2)
     # verify if data1 and data2 have the same number of rows
     .check_that(nrow(data1) == nrow(data2))
     # are the names of the bands different?
@@ -72,13 +75,15 @@ sits_merge.sits <- function(data1, data2, ..., suffix = c(".1", ".2")) {
     coincidences1 <- bands1 %in% bands2
     coincidences2 <- bands2 %in% bands1
     if (any(coincidences1) || any(coincidences2)) {
-        bands1_names <- rep(x = suffix[[1]], length(coincidences1))
-        bands2_names <- rep(x = suffix[[2]], length(coincidences2))
-        bands1[coincidences1] <- paste0(bands1[coincidences1],
-                                        bands1_names[coincidences1]
+        bands1_names <- rep(x = suffix[[1L]], length(coincidences1))
+        bands2_names <- rep(x = suffix[[2L]], length(coincidences2))
+        bands1[coincidences1] <- paste0(
+            bands1[coincidences1],
+            bands1_names[coincidences1]
         )
-        bands2[coincidences2] <- paste0(bands2[coincidences2],
-                                        bands2_names[coincidences2]
+        bands2[coincidences2] <- paste0(
+            bands2[coincidences2],
+            bands2_names[coincidences2]
         )
         .check_that(!any(bands1 %in% bands2))
         .check_that(!any(bands2 %in% bands1))
@@ -92,11 +97,10 @@ sits_merge.sits <- function(data1, data2, ..., suffix = c(".1", ".2")) {
         data1[["time_series"]],
         data2[["time_series"]],
         function(ts1, ts2) {
-            ts3 <- dplyr::bind_cols(ts1, dplyr::select(ts2, -"Index"))
-            return(ts3)
+            dplyr::bind_cols(ts1, dplyr::select(ts2, -"Index"))
         }
     )
-    return(result)
+    result
 }
 
 #' @rdname sits_merge
@@ -107,19 +111,19 @@ sits_merge.raster_cube <- function(data1, data2, ...) {
     .check_is_raster_cube(data1)
     .check_is_raster_cube(data2)
     # merge cubes
-    merged_cube <- .merge_switch(
-        data1 = data1, data2 = data2,
-        dem_case       = .merge_dem(data1, data2),
-        hls_case       = .merge_hls(data1, data2),
-        regular_case   = .merge_regular(data1, data2),
-        irregular_case = .merge_irregular(data1, data2)
-    )
-    # return
-    merged_cube
+    .merge(data1, data2)
 }
 
 #' @rdname sits_merge
 #' @export
 sits_merge.default <- function(data1, data2, ...) {
-    stop(.conf("messages", "sits_merge_default"))
+    data1 <- tibble::as_tibble(data1)
+    if (all(.conf("sits_cube_cols") %in% colnames(data1))) {
+        data1 <- .cube_find_class(data1)
+    } else if (all(.conf("sits_tibble_cols") %in% colnames(data1))) {
+        class(data1) <- c("sits", class(data1))
+    } else {
+        stop(.conf("messages", "sits_merge_default"))
+    }
+    sits_merge(data1, data2, ...)
 }
