@@ -1,21 +1,27 @@
 #' @title Tuning machine learning models hyper-parameters
 #' @name sits_tuning
 #'
-#' @author Rolf Simoes, \email{rolf.simoes@@inpe.br}
+#' @author Rolf Simoes, \email{rolfsimoes@@gmail.com}
 #' @description
+#' This function performs a random search on values of selected hyperparameters,
+#' and produces a data frame with the accuracy and kappa values produced
+#' by a validation procedure. The result allows users to select appropriate
+#' hyperparameters for deep learning models.
+#'
+#' @note
 #' Machine learning models use stochastic gradient descent (SGD) techniques to
 #' find optimal solutions. To perform SGD, models use optimization
 #' algorithms which have hyperparameters that have to be adjusted
 #' to achieve best performance for each application.
-#'
-#' This function performs a random search on values of selected hyperparameters.
+#
 #' Instead of performing an exhaustive test of all parameter combinations,
-#' it selecting them randomly. Validation is done using an independent set
+#' \code{sits_tuning} selects them randomly.
+#' Validation is done using an independent set
 #' of samples or by a validation split.  The function returns the
 #' best hyper-parameters in a list. Hyper-parameters passed to \code{params}
-#' parameter should be passed by calling \code{sits_tuning_hparams()}.
+#' parameter should be passed by calling
+#' \code{\link[sits]{sits_tuning_hparams}}.
 #'
-#' @note
 #'    When using a GPU for deep learning, \code{gpu_memory} indicates the
 #'    memory of the graphics card which is available for processing.
 #'    The parameter \code{batch_size} defines the size of the matrix
@@ -51,7 +57,7 @@
 #'   \code{ml_method}. User can use \code{uniform}, \code{choice},
 #'   \code{randint}, \code{normal}, \code{lognormal}, \code{loguniform},
 #'   and \code{beta} distribution functions to randomize parameters.
-#' @param  trials            Number of random trials to perform the random search.
+#' @param  trials            Number of random trials to perform the search.
 #' @param  progress          Show progress bar?
 #' @param  multicores        Number of cores to process in parallel.
 #' @param  gpu_memory        Memory available in GPU in GB (default = 4)
@@ -59,7 +65,7 @@
 #'
 #' @return
 #' A tibble containing all parameters used to train on each trial
-#'   ordered by accuracy
+#'   ordered by accuracy.
 #'
 #' @examples
 #' if (sits_run_examples()) {
@@ -93,13 +99,13 @@ sits_tuning <- function(samples,
                         params = sits_tuning_hparams(
                             optimizer = torch::optim_adamw,
                             opt_hparams = list(
-                                lr = loguniform(10^-2, 10^-4)
+                                lr = loguniform(0.01, 0.0001)
                             )
                         ),
-                        trials = 30,
-                        multicores = 2,
-                        gpu_memory = 4,
-                        batch_size = 2^gpu_memory,
+                        trials = 30L,
+                        multicores = 2L,
+                        gpu_memory = 4L,
+                        batch_size = 2L^gpu_memory,
                         progress = FALSE) {
     # set caller to show in errors
     .check_set_caller("sits_tuning")
@@ -111,15 +117,16 @@ sits_tuning <- function(samples,
         .check_samples_train(samples_validation)
     } else {
         # check validation_split parameter if samples_validation is not passed
-        .check_num_parameter(validation_split, exclusive_min = 0, max = 0.5)
+        .check_num_parameter(validation_split, exclusive_min = 0.0, max = 0.5)
     }
     # check 'ml_functions' parameter
     ml_function <- substitute(ml_method, env = environment())
-    if (is.call(ml_function))
-        ml_function <- ml_function[[1]]
+    if (is.call(ml_function)) {
+        ml_function <- ml_function[[1L]]
+    }
     ml_function <- eval(ml_function, envir = asNamespace("sits"))
     # check 'params' parameter
-    .check_lst_parameter(params, len_min = 1)
+    .check_lst_parameter(params, len_min = 1L)
     .check_that(!"samples" %in% names(params),
         msg = .conf("messages", "sits_tuning_samples")
     )
@@ -133,7 +140,9 @@ sits_tuning <- function(samples,
     # check trials
     .check_int_parameter(trials)
     # check 'multicores' parameter
-    .check_int_parameter(multicores, min = 1, max = 2048)
+    .check_int_parameter(multicores, min = 1L, max = 2048L)
+    # show progress bar?
+    progress <- .message_progress(progress)
     # generate random params
     params_lst <- purrr::map(
         as.list(seq_len(trials)),
@@ -144,8 +153,9 @@ sits_tuning <- function(samples,
     sits_env[["batch_size"]] <- batch_size
     # Update multicores
     if (.torch_gpu_classification() &&
-        "optimizer" %in% ls(environment(ml_method)))
-        multicores <-  1
+        "optimizer" %in% ls(environment(ml_method))) {
+        multicores <- 1L
+    }
     # start processes
     .parallel_start(workers = multicores)
     on.exit(.parallel_stop())
@@ -170,8 +180,8 @@ sits_tuning <- function(samples,
         )
         # Remove variable 'ml_method'
         remove(ml_method)
-        return(result)
-    }, progress = progress, n_retries = 0)
+        result
+    }, progress = progress, n_retries = 0L)
 
     # prepare result
     result <- dplyr::bind_rows(result_lst)
@@ -183,7 +193,7 @@ sits_tuning <- function(samples,
     tuning_tb <- dplyr::arrange(tuning_tb, dplyr::desc(.data[["accuracy"]]))
     # prepare result class
     class(tuning_tb) <- c("sits_tuned", class(tuning_tb))
-    return(tuning_tb)
+    tuning_tb
 }
 #' @title Tuning machine learning models hyper-parameters
 #' @name sits_tuning_hparams
@@ -233,8 +243,8 @@ sits_tuning <- function(samples,
 #'                 torch::optim_adagrad
 #'             ),
 #'             opt_hparams = list(
-#'                  lr = loguniform(10^-2, 10^-4),
-#'                  weight_decay = loguniform(10^-2, 10^-8)
+#'                 lr = loguniform(10^-2, 10^-4),
+#'                 weight_decay = loguniform(10^-2, 10^-8)
 #'             )
 #'         ),
 #'         trials = 20,
@@ -247,6 +257,6 @@ sits_tuning <- function(samples,
 #'
 sits_tuning_hparams <- function(...) {
     params <- substitute(list(...), environment())
-    params <- as.list(params)[-1]
-    return(params)
+    params <- as.list(params)[-1L]
+    params
 }
